@@ -31,6 +31,10 @@ from python_framework.api.src.converter import ActuatorHealthConverter
 from python_framework.api.src.service import ActuatorHealthService
 from python_framework.api.src.repository import ActuatorHealthRepository
 
+from python_framework.api.src.controller import DocumentationController
+from python_framework.api.src.service import DocumentationService
+from python_framework.api.src.repository import DocumentationRepository
+
 from python_framework.api.src.annotation.EnumAnnotation import *
 from python_framework.api.src.service.flask.FlaskManager import *
 from python_framework.api.src.annotation.SchedulerAnnotation import *
